@@ -3,7 +3,7 @@
  *  Series expansion test (Laurent and Taylor series). */
 
 /*
- *  GiNaC Copyright (C) 1999-2007 Johannes Gutenberg University Mainz, Germany
+ *  GiNaC Copyright (C) 1999-2008 Johannes Gutenberg University Mainz, Germany
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,7 +20,10 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "exams.h"
+#include <iostream>
+#include "ginac.h"
+using namespace std;
+using namespace GiNaC;
 
 static symbol x("x");
 
@@ -367,7 +370,6 @@ unsigned exam_pseries()
 	unsigned result = 0;
 	
 	cout << "examining series expansion" << flush;
-	clog << "----------series expansion:" << endl;
 	
 	result += exam_series1();  cout << '.' << flush;
 	result += exam_series2();  cout << '.' << flush;
@@ -383,11 +385,10 @@ unsigned exam_pseries()
 	result += exam_series12();  cout << '.' << flush;
 	result += exam_series13();  cout << '.' << flush;
 	
-	if (!result) {
-		cout << " passed " << endl;
-		clog << "(no output)" << endl;
-	} else {
-		cout << " failed " << endl;
-	}
 	return result;
 }
+
+int main(int argc, char** argv)
+{
+	return exam_pseries();
+}
