@@ -89,7 +89,7 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 29 "/user/jensv/ginac/ginac/ginac/input_parser.yy"
+#line 29 "/user/jensv/ginac/GiNaC/ginac/input_parser.yy"
 
 #include <stdexcept>
 
@@ -1080,7 +1080,7 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 82 "/user/jensv/ginac/ginac/ginac/input_parser.yy"
+#line 82 "/user/jensv/ginac/GiNaC/ginac/input_parser.yy"
     {
 		try {
 			parsed_ex = yyvsp[-1];
@@ -1093,12 +1093,12 @@ yyreduce:
     break;
 
   case 3:
-#line 93 "/user/jensv/ginac/ginac/ginac/input_parser.yy"
+#line 93 "/user/jensv/ginac/GiNaC/ginac/input_parser.yy"
     {yyval = yyvsp[0];}
     break;
 
   case 4:
-#line 94 "/user/jensv/ginac/ginac/ginac/input_parser.yy"
+#line 94 "/user/jensv/ginac/GiNaC/ginac/input_parser.yy"
     {
 		if (is_lexer_symbol_predefined(yyvsp[0]))
 			yyval = yyvsp[0].eval();
@@ -1108,17 +1108,17 @@ yyreduce:
     break;
 
   case 5:
-#line 100 "/user/jensv/ginac/ginac/ginac/input_parser.yy"
+#line 100 "/user/jensv/ginac/GiNaC/ginac/input_parser.yy"
     {yyval = yyvsp[0];}
     break;
 
   case 6:
-#line 101 "/user/jensv/ginac/ginac/ginac/input_parser.yy"
+#line 101 "/user/jensv/ginac/GiNaC/ginac/input_parser.yy"
     {yyval = yyvsp[0];}
     break;
 
   case 7:
-#line 102 "/user/jensv/ginac/ginac/ginac/input_parser.yy"
+#line 102 "/user/jensv/ginac/GiNaC/ginac/input_parser.yy"
     {
 		std::string n = get_symbol_name(yyvsp[-3]);
 		if (n == "sqrt") {
@@ -1137,147 +1137,147 @@ yyreduce:
     break;
 
   case 8:
-#line 117 "/user/jensv/ginac/ginac/ginac/input_parser.yy"
+#line 117 "/user/jensv/ginac/GiNaC/ginac/input_parser.yy"
     {yyval = yyvsp[-2] == yyvsp[0];}
     break;
 
   case 9:
-#line 118 "/user/jensv/ginac/ginac/ginac/input_parser.yy"
+#line 118 "/user/jensv/ginac/GiNaC/ginac/input_parser.yy"
     {yyval = yyvsp[-2] != yyvsp[0];}
     break;
 
   case 10:
-#line 119 "/user/jensv/ginac/ginac/ginac/input_parser.yy"
+#line 119 "/user/jensv/ginac/GiNaC/ginac/input_parser.yy"
     {yyval = yyvsp[-2] < yyvsp[0];}
     break;
 
   case 11:
-#line 120 "/user/jensv/ginac/ginac/ginac/input_parser.yy"
+#line 120 "/user/jensv/ginac/GiNaC/ginac/input_parser.yy"
     {yyval = yyvsp[-2] <= yyvsp[0];}
     break;
 
   case 12:
-#line 121 "/user/jensv/ginac/ginac/ginac/input_parser.yy"
+#line 121 "/user/jensv/ginac/GiNaC/ginac/input_parser.yy"
     {yyval = yyvsp[-2] > yyvsp[0];}
     break;
 
   case 13:
-#line 122 "/user/jensv/ginac/ginac/ginac/input_parser.yy"
+#line 122 "/user/jensv/ginac/GiNaC/ginac/input_parser.yy"
     {yyval = yyvsp[-2] >= yyvsp[0];}
     break;
 
   case 14:
-#line 123 "/user/jensv/ginac/ginac/ginac/input_parser.yy"
+#line 123 "/user/jensv/ginac/GiNaC/ginac/input_parser.yy"
     {yyval = yyvsp[-2] + yyvsp[0];}
     break;
 
   case 15:
-#line 124 "/user/jensv/ginac/ginac/ginac/input_parser.yy"
+#line 124 "/user/jensv/ginac/GiNaC/ginac/input_parser.yy"
     {yyval = yyvsp[-2] - yyvsp[0];}
     break;
 
   case 16:
-#line 125 "/user/jensv/ginac/ginac/ginac/input_parser.yy"
+#line 125 "/user/jensv/ginac/GiNaC/ginac/input_parser.yy"
     {yyval = yyvsp[-2] * yyvsp[0];}
     break;
 
   case 17:
-#line 126 "/user/jensv/ginac/ginac/ginac/input_parser.yy"
+#line 126 "/user/jensv/ginac/GiNaC/ginac/input_parser.yy"
     {yyval = yyvsp[-2] / yyvsp[0];}
     break;
 
   case 18:
-#line 127 "/user/jensv/ginac/ginac/ginac/input_parser.yy"
+#line 127 "/user/jensv/ginac/GiNaC/ginac/input_parser.yy"
     {yyval = -yyvsp[0];}
     break;
 
   case 19:
-#line 128 "/user/jensv/ginac/ginac/ginac/input_parser.yy"
+#line 128 "/user/jensv/ginac/GiNaC/ginac/input_parser.yy"
     {yyval = yyvsp[0];}
     break;
 
   case 20:
-#line 129 "/user/jensv/ginac/ginac/ginac/input_parser.yy"
+#line 129 "/user/jensv/ginac/GiNaC/ginac/input_parser.yy"
     {yyval = pow(yyvsp[-2], yyvsp[0]);}
     break;
 
   case 21:
-#line 130 "/user/jensv/ginac/ginac/ginac/input_parser.yy"
+#line 130 "/user/jensv/ginac/GiNaC/ginac/input_parser.yy"
     {yyval = attach_index(yyvsp[-2], yyvsp[0], true);}
     break;
 
   case 22:
-#line 131 "/user/jensv/ginac/ginac/ginac/input_parser.yy"
+#line 131 "/user/jensv/ginac/GiNaC/ginac/input_parser.yy"
     {yyval = attach_index(yyvsp[-2], yyvsp[0], false);}
     break;
 
   case 23:
-#line 132 "/user/jensv/ginac/ginac/ginac/input_parser.yy"
+#line 132 "/user/jensv/ginac/GiNaC/ginac/input_parser.yy"
     {yyval = factorial(yyvsp[-1]);}
     break;
 
   case 24:
-#line 133 "/user/jensv/ginac/ginac/ginac/input_parser.yy"
+#line 133 "/user/jensv/ginac/GiNaC/ginac/input_parser.yy"
     {yyval = yyvsp[-1];}
     break;
 
   case 25:
-#line 134 "/user/jensv/ginac/ginac/ginac/input_parser.yy"
+#line 134 "/user/jensv/ginac/GiNaC/ginac/input_parser.yy"
     {yyval = yyvsp[-1];}
     break;
 
   case 26:
-#line 135 "/user/jensv/ginac/ginac/ginac/input_parser.yy"
+#line 135 "/user/jensv/ginac/GiNaC/ginac/input_parser.yy"
     {yyval = lst_to_matrix(ex_to<lst>(yyvsp[-1]));}
     break;
 
   case 27:
-#line 138 "/user/jensv/ginac/ginac/ginac/input_parser.yy"
+#line 138 "/user/jensv/ginac/GiNaC/ginac/input_parser.yy"
     {yyval = exprseq(yyvsp[0]);}
     break;
 
   case 28:
-#line 139 "/user/jensv/ginac/ginac/ginac/input_parser.yy"
+#line 139 "/user/jensv/ginac/GiNaC/ginac/input_parser.yy"
     {exprseq es(ex_to<exprseq>(yyvsp[-2])); yyval = es.append(yyvsp[0]);}
     break;
 
   case 29:
-#line 142 "/user/jensv/ginac/ginac/ginac/input_parser.yy"
+#line 142 "/user/jensv/ginac/GiNaC/ginac/input_parser.yy"
     {yyval = *new lst;}
     break;
 
   case 30:
-#line 143 "/user/jensv/ginac/ginac/ginac/input_parser.yy"
+#line 143 "/user/jensv/ginac/GiNaC/ginac/input_parser.yy"
     {yyval = yyvsp[0];}
     break;
 
   case 31:
-#line 146 "/user/jensv/ginac/ginac/ginac/input_parser.yy"
+#line 146 "/user/jensv/ginac/GiNaC/ginac/input_parser.yy"
     {yyval = lst(yyvsp[0]);}
     break;
 
   case 32:
-#line 147 "/user/jensv/ginac/ginac/ginac/input_parser.yy"
+#line 147 "/user/jensv/ginac/GiNaC/ginac/input_parser.yy"
     {lst l(ex_to<lst>(yyvsp[-2])); yyval = l.append(yyvsp[0]);}
     break;
 
   case 33:
-#line 150 "/user/jensv/ginac/ginac/ginac/input_parser.yy"
+#line 150 "/user/jensv/ginac/GiNaC/ginac/input_parser.yy"
     {yyval = lst(yyvsp[-1]);}
     break;
 
   case 34:
-#line 151 "/user/jensv/ginac/ginac/ginac/input_parser.yy"
+#line 151 "/user/jensv/ginac/GiNaC/ginac/input_parser.yy"
     {lst l(ex_to<lst>(yyvsp[-4])); yyval = l.append(yyvsp[-1]);}
     break;
 
   case 35:
-#line 154 "/user/jensv/ginac/ginac/ginac/input_parser.yy"
+#line 154 "/user/jensv/ginac/GiNaC/ginac/input_parser.yy"
     {yyval = lst(yyvsp[0]);}
     break;
 
   case 36:
-#line 155 "/user/jensv/ginac/ginac/ginac/input_parser.yy"
+#line 155 "/user/jensv/ginac/GiNaC/ginac/input_parser.yy"
     {lst l(ex_to<lst>(yyvsp[-2])); yyval = l.append(yyvsp[0]);}
     break;
 
@@ -1510,7 +1510,7 @@ yyreturn:
 }
 
 
-#line 163 "/user/jensv/ginac/ginac/ginac/input_parser.yy"
+#line 163 "/user/jensv/ginac/GiNaC/ginac/input_parser.yy"
 
 // Attach index to expression
 ex attach_index(const ex & base, ex i, bool covariant)
