@@ -24,10 +24,15 @@
 #ifndef __GINAC_UTILS_H__
 #define __GINAC_UTILS_H__
 
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
 
 #include <string>
 #include <functional>
+#ifdef HAVE_STDINT_H
+#include <stdint.h> // for uintptr_t
+#endif
 
 #include "assertion.h"
 
@@ -58,12 +63,8 @@ inline int compare_pointers(const T * a, const T * b)
 	return 0;
 }
 
-#if SIZEOF_VOID_P == SIZEOF_INT
-typedef unsigned int p_int;
-#elif SIZEOF_VOID_P == SIZEOF_LONG
-typedef unsigned long p_int;
-#elif SIZEOF_VOID_P == SIZEOF_LONG_LONG
-typedef unsigned long long p_int;
+#ifdef HAVE_STDINT_H
+typedef uintptr_t p_int;
 #else
 typedef unsigned long p_int;
 #endif
@@ -73,24 +74,26 @@ inline unsigned golden_ratio_hash(p_int n)
 {
 	// This function works much better when fast arithmetic with at
 	// least 64 significant bits is available.
-#if SIZEOF_LONG >= 8
+	if (sizeof(long) >= 8) {
 	// So 'long' has 64 bits.  Excellent!  We prefer it because it might be
 	// more efficient than 'long long'.
 	unsigned long l = n * 0x4f1bbcddUL;
 	return (unsigned)l;
-#elif SIZEOF_LONG_LONG >= 8
+	}
+#ifdef HAVE_LONG_LONG
+	else if (sizeof(long long) >= 8) {
 	// This requires 'long long' (or an equivalent 64 bit type)---which is,
 	// unfortunately, not ANSI-C++-compliant.
 	// (Yet C99 demands it, which is reason for hope.)
 	unsigned long long l = n * 0x4f1bbcddULL;
 	return (unsigned)l;
-#else
+	}
+#endif
 	// Without a type with 64 significant bits do the multiplication manually
 	// by splitting n up into the lower and upper two bytes.
 	const unsigned n0 = (n & 0x0000ffffU);
 	const unsigned n1 = (n & 0xffff0000U) >> 16;
 	return (n0 * 0x0000bcddU) + ((n1 * 0x0000bcddU + n0 * 0x00004f1bU) << 16);
-#endif
 }
 
 /* Compute the sign of a permutation of a container, with and without an
